@@ -3,6 +3,7 @@ import os
 orig_path = os.getcwd()
 install_path = os.path.abspath(__file__)[:-12]
 os.chdir(install_path)
+lib_path = install_path + "/pyseing/src/build/pyseing*"
 
 if not os.path.isdir("pyseing"):
     os.system("git clone https://github.com/AMKCode/pyseing.git")
@@ -12,10 +13,13 @@ if not os.path.isdir("pyseing"):
     os.chdir("./build")
     os.system("cmake ..")
     os.system("make")
-    os.chdir("..")
-    os.chdir("..")
-    os.chdir("..")
-    os.system("cp ./pyseing/src/build/pyseing* .")
-    os.chdir(orig_path)
-    
+
+   # os.chdir("..")
+   # os.chdir("..")
+   # os.chdir("..")
+   # os.system("cp ./pyseing/src/build/pyseing* .")
+
+os.chdir(orig_path)
+os.system("cp " + lib_path + " .")
+
 import pyseing
